@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: timings.c,v 1.4.2.2.2.1 2002/01/14 00:56:50 baddog Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -70,20 +70,17 @@ int
 main (int argc, char *argv [])
 {
 	glibtop_union data;
-	glibtop_sysdeps sysdeps;
-	unsigned c, count, port, i, *ptr;
+	unsigned c, count, *ptr;
 	struct rusage total_start, total_end;
 	struct rusage rusage_start, rusage_end;
 	struct timeval elapsed_utime, elapsed_stime;
-	char buffer [BUFSIZ];
-	pid_t pid, ppid;
-	char *args;
+	pid_t pid;
 
 	count = PROFILE_COUNT;
 
 	setlocale (LC_ALL, "");
-	bindtextdomain (PACKAGE, GTOPLOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
+	textdomain (GETTEXT_PACKAGE);
 
 	printf ("%-12s (%-10s): %7s - %9s - %9s\n",
 		"Feature", "Flags", "Count", "utime", "stime");
