@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procmem.c,v 1.14.2.1 1999/05/27 19:24:22 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -47,64 +45,60 @@ static int pageshift;		/* log base 2 of the pagesize */
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_mem_s (glibtop *server)
 {
-    register int pagesize;
+	register int pagesize;
 
-    server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem |
-	_glibtop_sysdeps_proc_mem_statm;
+	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem |
+	  _glibtop_sysdeps_proc_mem_statm;
 
-    /* get the page size with "getpagesize" and calculate pageshift
-     * from it */
-    pagesize = getpagesize ();
-    pageshift = 0;
-    while (pagesize > 1) {
-	pageshift++;
-	pagesize >>= 1;
-    }
-
-    return 0;
+	/* get the page size with "getpagesize" and calculate pageshift
+	 * from it */
+	pagesize = getpagesize ();
+	pageshift = 0;
+	while (pagesize > 1) {
+		pageshift++;
+		pagesize >>= 1;
+	}
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf, pid_t pid)
 {
-    char buffer [BUFSIZ], *p;
+	char buffer [BUFSIZ], *p;
 	
-    glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
+	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
 
-    memset (buf, 0, sizeof (glibtop_proc_mem));
+	memset (buf, 0, sizeof (glibtop_proc_mem));
 
-    if (proc_stat_to_buffer (buffer, pid))
-	return -1;
+	if (proc_stat_to_buffer (buffer, pid))
+		return;
 
-    p = proc_stat_after_cmd (buffer);
-    if (!p) return -1;
+	p = proc_stat_after_cmd (buffer);
+	if (!p) return;
 
-    p = skip_multiple_token (p, 20);
+	p = skip_multiple_token (p, 20);
 
-    buf->vsize = strtoul (p, &p, 0);
-    buf->rss = strtoul (p, &p, 0);
-    buf->rss_rlim = strtoul (p, &p, 0);
+	buf->vsize = strtoul (p, &p, 0);
+	buf->rss = strtoul (p, &p, 0);
+	buf->rss_rlim = strtoul (p, &p, 0);
 
-    buf->flags = _glibtop_sysdeps_proc_mem;
+	buf->flags = _glibtop_sysdeps_proc_mem;
 
-    if (proc_statm_to_buffer (buffer, pid))
-	return -1;
+	if (proc_statm_to_buffer (buffer, pid))
+		return;
 
-    buf->size = strtoul (buffer, &p, 0);
-    buf->resident = strtoul (p, &p, 0);
-    buf->share = strtoul (p, &p, 0);
+	buf->size = strtoul (buffer, &p, 0);
+	buf->resident = strtoul (p, &p, 0);
+	buf->share = strtoul (p, &p, 0);
 
-    buf->size <<= pageshift;
-    buf->resident <<= pageshift;
-    buf->share <<= pageshift;
-    buf->rss <<= pageshift;
+	buf->size <<= pageshift;
+	buf->resident <<= pageshift;
+	buf->share <<= pageshift;
+	buf->rss <<= pageshift;
 
-    buf->flags |= _glibtop_sysdeps_proc_mem_statm;
-
-    return 0;
+	buf->flags |= _glibtop_sysdeps_proc_mem_statm;
 }
