@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: cpu.c,v 1.3 1999/02/23 11:46:40 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -33,22 +31,18 @@ static const unsigned long _glibtop_sysdeps_cpu = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_cpu_p (glibtop *server)
 {
-    server->sysdeps.cpu = _glibtop_sysdeps_cpu;
-
-    return 0;
+	server->sysdeps.cpu = _glibtop_sysdeps_cpu;
 }
 
 /* Provides information about cpu usage. */
 
-int
+void
 glibtop_get_cpu_p (glibtop *server, glibtop_cpu *buf)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_CPU, 0);
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_CPU, 0);
 	
-    memset (buf, 0, sizeof (glibtop_cpu));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_cpu));
 }
