@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: proctime.c,v 1.8 1999/02/23 11:47:29 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,34 +27,34 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_proc_time =
-(1L << GLIBTOP_PROC_TIME_START_TIME) + (1L << GLIBTOP_PROC_TIME_UTIME);
+(1 << GLIBTOP_PROC_TIME_START_TIME) + (1 << GLIBTOP_PROC_TIME_UTIME);
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 			 pid_t pid)
 {
-    struct proc *pp;
+	struct proc *pp;
 
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_TIME), 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_TIME), 0);
 
-    memset (buf, 0, sizeof (glibtop_proc_time));
+	memset (buf, 0, sizeof (glibtop_proc_time));
 
-    /* Read process table from kernel. */	
+	/* Read process table from kernel. */	
 
-    _glibtop_read_proc_table (server);
+	_glibtop_read_proc_table (server);
 
-    /* Find the pid in the process table. */
+	/* Find the pid in the process table. */
 
-    pp = _glibtop_find_pid (server, pid);
+	pp = _glibtop_find_pid (server, pid);
 
-    if (pp == NULL)	return;
+	if (pp == NULL)	return;
 
-    /* Fill in data fields. */
+	/* Fill in data fields. */
 
-    buf->start_time = pp->p_time;
-    buf->utime = pp->p_cpticks;
+	buf->start_time = pp->p_time;
+	buf->utime = pp->p_cpticks;
 
-    buf->flags = _glibtop_sysdeps_proc_time;
+	buf->flags = _glibtop_sysdeps_proc_time;
 }
